@@ -26,10 +26,6 @@
 #include <libdrm/drm_fourcc.h>
 #include <unistd.h>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QtPlatformHeaders/QEGLNativeContext>
-#endif
-
 static void pwInit()
 {
     pw_init(nullptr, nullptr);
@@ -47,6 +43,7 @@ public:
 
     EGLImage m_image = nullptr;
     bool m_needsRecreateTexture = false;
+    bool m_allowDmaBuf = true;
 
     struct {
         QImage texture;
@@ -121,7 +118,7 @@ void PipeWireSourceItem::itemChange(QQuickItem::ItemChange change, const QQuickI
 
 void PipeWireSourceItem::releaseResources()
 {
-    if (window()) {
+    if (window() && (d->m_image || d->m_texture)) {
         window()->scheduleRenderJob(new DiscardEglPixmapRunnable(d->m_image, d->m_texture.take()), QQuickWindow::NoStage);
         d->m_image = EGL_NO_IMAGE_KHR;
     }
@@ -165,6 +162,7 @@ void PipeWireSourceItem::refresh()
     }
 
     if (d->m_nodeId == 0) {
+        releaseResources();
         d->m_stream.reset(nullptr);
         Q_EMIT streamSizeChanged();
 
@@ -173,8 +171,10 @@ void PipeWireSourceItem::refresh()
         };
     } else {
         d->m_stream.reset(new PipeWireSourceStream(this));
+        d->m_stream->setAllowDmaBuf(d->m_allowDmaBuf);
         Q_EMIT streamSizeChanged();
         connect(d->m_stream.get(), &PipeWireSourceStream::streamParametersChanged, this, &PipeWireSourceItem::streamSizeChanged);
+        connect(d->m_stream.get(), &PipeWireSourceStream::streamParametersChanged, this, &PipeWireSourceItem::usingDmaBufChanged);
 
         d->m_stream->createStream(d->m_nodeId, d->m_fd.value_or(0));
         if (!d->m_stream->error().isEmpty()) {
@@ -353,11 +353,7 @@ void PipeWireSourceItem::updateTextureDmaBuf(const DmaBufAttributes &attribs, sp
         return;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const auto openglContext = window()->openglContext();
-#else
     const auto openglContext = static_cast<QOpenGLContext *>(window()->rendererInterface()->getResource(window(), QSGRendererInterface::OpenGLContextResource));
-#endif
     if (!openglContext || !d->m_stream) {
         qCWarning(PIPEWIRE_LOGGING) << "need a window and a context" << window();
         return;
@@ -394,11 +390,7 @@ void PipeWireSourceItem::updateTextureDmaBuf(const DmaBufAttributes &attribs, sp
         QQuickWindow::CreateTextureOption textureOption =
             format == SPA_VIDEO_FORMAT_ARGB || format == SPA_VIDEO_FORMAT_BGRA ? QQuickWindow::TextureHasAlphaChannel : QQuickWindow::TextureIsOpaque;
         setEnabled(true);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        return window()->createTextureFromNativeObject(QQuickWindow::NativeObjectTexture, &textureId, 0 /*a vulkan thing?*/, size, textureOption);
-#else
         return QNativeInterface::QSGOpenGLTexture::fromNative(textureId, window(), size, textureOption);
-#endif
     };
 }
 
@@ -461,3 +453,23 @@ QSize PipeWireSourceItem::streamSize() const
     }
     return d->m_stream->size();
 }
+
+bool PipeWireSourceItem::usingDmaBuf() const
+{
+    return d->m_stream && d->m_stream->usingDmaBuf();
+}
+
+bool PipeWireSourceItem::allowDmaBuf() const
+{
+    return d->m_stream && d->m_stream->allowDmaBuf();
+}
+
+void PipeWireSourceItem::setAllowDmaBuf(bool allowed)
+{
+    d->m_allowDmaBuf = allowed;
+    if (d->m_stream) {
+        d->m_stream->setAllowDmaBuf(allowed);
+    }
+}
+
+#include "moc_pipewiresourceitem.cpp"
